/* Copyright © 2012 Matthew Champion
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of mattunderscore.com nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MATTHEW CHAMPION BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */

package com.mattunderscore.filter.contentnegotiation.parser;

import com.mattunderscore.http.headers.Qualified;

/**
 * Cross product used to combine the quality and quality of source values for a
 * variant.
 * 
 * @author Matt Champion
 * @since 0.0.13
 */
public class CrossProduct implements Qualified
{

    private Qualified q0;
    private Qualified q1;
    private Variant variant;

    public CrossProduct(Qualified q0, Qualified q1, Variant variant)
    {
        this.q0 = q0;
        this.q1 = q1;
        this.variant = variant;
    }

    @Override
    public double getQualifier()
    {
        return q0.getQualifier() * q1.getQualifier();
    }

    /**
     * Returns the server's variant associated with the cross product. 
     * @return Variant of cross product
     */
    public Variant getVariant()
    {
        return variant;
    }
}
